package com.tfis.system.service.impl;

import java.util.List;
import com.tfis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.tfis.system.mapper.AircraftSubsystemMapper;
import com.tfis.system.domain.AircraftSubsystem;
import com.tfis.system.service.IAircraftSubsystemService;

/**
 * 分系统信息管理Service业务层处理
 * 
 * @author allen
 * @date 2023-11-23
 */
@Service
public class AircraftSubsystemServiceImpl implements IAircraftSubsystemService 
{
    @Autowired
    private AircraftSubsystemMapper aircraftSubsystemMapper;

    /**
     * 查询分系统信息管理
     * 
     * @param id 分系统信息管理主键
     * @return 分系统信息管理
     */
    @Override
    public AircraftSubsystem selectAircraftSubsystemById(Long id)
    {
        return aircraftSubsystemMapper.selectAircraftSubsystemById(id);
    }

    /**
     * 查询分系统信息管理列表
     * 
     * @param aircraftSubsystem 分系统信息管理
     * @return 分系统信息管理
     */
    @Override
    public List<AircraftSubsystem> selectAircraftSubsystemList(AircraftSubsystem aircraftSubsystem)
    {
        return aircraftSubsystemMapper.selectAircraftSubsystemList(aircraftSubsystem);
    }

    /**
     * 新增分系统信息管理
     * 
     * @param aircraftSubsystem 分系统信息管理
     * @return 结果
     */
    @Override
    public int insertAircraftSubsystem(AircraftSubsystem aircraftSubsystem)
    {
        aircraftSubsystem.setCreateTime(DateUtils.getNowDate());
        return aircraftSubsystemMapper.insertAircraftSubsystem(aircraftSubsystem);
    }

    /**
     * 修改分系统信息管理
     * 
     * @param aircraftSubsystem 分系统信息管理
     * @return 结果
     */
    @Override
    public int updateAircraftSubsystem(AircraftSubsystem aircraftSubsystem)
    {
        aircraftSubsystem.setUpdateTime(DateUtils.getNowDate());
        return aircraftSubsystemMapper.updateAircraftSubsystem(aircraftSubsystem);
    }

    /**
     * 批量删除分系统信息管理
     * 
     * @param ids 需要删除的分系统信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAircraftSubsystemByIds(Long[] ids)
    {
        return aircraftSubsystemMapper.deleteAircraftSubsystemByIds(ids);
    }

    /**
     * 删除分系统信息管理信息
     * 
     * @param id 分系统信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAircraftSubsystemById(Long id)
    {
        return aircraftSubsystemMapper.deleteAircraftSubsystemById(id);
    }

    @Override
    public List getSubSystemOption(Long aircraftsystemid){
        return aircraftSubsystemMapper.getSubSystemOption(aircraftsystemid);
    }


    @Override
    public List getSubOption() {
        return aircraftSubsystemMapper.getSubOption();
    }

}
