package com.tfis.system.service.impl;

import java.util.List;
import java.util.Map;

import com.tfis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.tfis.system.mapper.AircraftTypeMapper;
import com.tfis.system.domain.AircraftType;
import com.tfis.system.service.IAircraftTypeService;

/**
 * 机型信息管理Service业务层处理
 * 
 * @author allen
 * @date 2023-11-23
 */
@Service
public class AircraftTypeServiceImpl implements IAircraftTypeService 
{
    @Autowired
    private AircraftTypeMapper aircraftTypeMapper;

    /**
     * 查询机型信息管理
     * 
     * @param id 机型信息管理主键
     * @return 机型信息管理
     */
    @Override
    public AircraftType selectAircraftTypeById(Long id)
    {
        return aircraftTypeMapper.selectAircraftTypeById(id);
    }

    /**
     * 查询机型信息管理列表
     * 
     * @param aircraftType 机型信息管理
     * @return 机型信息管理
     */
    @Override
    public List<AircraftType> selectAircraftTypeList(AircraftType aircraftType)
    {
        return aircraftTypeMapper.selectAircraftTypeList(aircraftType);
    }

    /**
     * 新增机型信息管理
     * 
     * @param aircraftType 机型信息管理
     * @return 结果
     */
    @Override
    public int insertAircraftType(AircraftType aircraftType)
    {
        aircraftType.setCreateTime(DateUtils.getNowDate());
        return aircraftTypeMapper.insertAircraftType(aircraftType);
    }

    /**
     * 修改机型信息管理
     * 
     * @param aircraftType 机型信息管理
     * @return 结果
     */
    @Override
    public int updateAircraftType(AircraftType aircraftType)
    {
        aircraftType.setUpdateTime(DateUtils.getNowDate());
        return aircraftTypeMapper.updateAircraftType(aircraftType);
    }

    /**
     * 批量删除机型信息管理
     * 
     * @param ids 需要删除的机型信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAircraftTypeByIds(Long[] ids)
    {
        return aircraftTypeMapper.deleteAircraftTypeByIds(ids);
    }

    /**
     * 删除机型信息管理信息
     * 
     * @param id 机型信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAircraftTypeById(Long id)
    {
        return aircraftTypeMapper.deleteAircraftTypeById(id);
    }

    @Override
    public List getOption() {
        return aircraftTypeMapper.getOption();
    }
}
