package com.tfis.system.service.impl;

import java.util.List;
import com.tfis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.tfis.system.mapper.FaultCaseMapper;
import com.tfis.system.domain.FaultCase;
import com.tfis.system.service.IFaultCaseService;

/**
 * 故障案例管理Service业务层处理
 * 
 * @author allen
 * @date 2023-11-23
 */
@Service
public class FaultCaseServiceImpl implements IFaultCaseService 
{
    @Autowired
    private FaultCaseMapper faultCaseMapper;

    /**
     * 查询故障案例管理
     * 
     * @param id 故障案例管理主键
     * @return 故障案例管理
     */
    @Override
    public FaultCase selectFaultCaseById(Long id)
    {
        return faultCaseMapper.selectFaultCaseById(id);
    }

    /**
     * 查询故障案例管理列表
     * 
     * @param faultCase 故障案例管理
     * @return 故障案例管理
     */
    @Override
    public List<FaultCase> selectFaultCaseList(FaultCase faultCase)
    {
        return faultCaseMapper.selectFaultCaseList(faultCase);
    }

    /**
     * 新增故障案例管理
     * 
     * @param faultCase 故障案例管理
     * @return 结果
     */
    @Override
    public int insertFaultCase(FaultCase faultCase)
    {
        faultCase.setCreateTime(DateUtils.getNowDate());
        return faultCaseMapper.insertFaultCase(faultCase);
    }

    /**
     * 修改故障案例管理
     * 
     * @param faultCase 故障案例管理
     * @return 结果
     */
    @Override
    public int updateFaultCase(FaultCase faultCase)
    {
        faultCase.setUpdateTime(DateUtils.getNowDate());
        return faultCaseMapper.updateFaultCase(faultCase);
    }

    /**
     * 批量删除故障案例管理
     * 
     * @param ids 需要删除的故障案例管理主键
     * @return 结果
     */
    @Override
    public int deleteFaultCaseByIds(Long[] ids)
    {
        return faultCaseMapper.deleteFaultCaseByIds(ids);
    }

    /**
     * 删除故障案例管理信息
     * 
     * @param id 故障案例管理主键
     * @return 结果
     */
    @Override
    public int deleteFaultCaseById(Long id)
    {
        return faultCaseMapper.deleteFaultCaseById(id);
    }
}
